rbedrock represents database keys two different ways. chrkeys are a
human-readable format understood by most functions. rawkeys are used
internally, by the methods of bedrockdb objects and bedrock_leveldb_*
functions.
rbedrock represents database keys two different ways. chrkeys are a
human-readable format understood by most functions. rawkeys are used
internally, by the methods of bedrockdb objects and bedrock_leveldb_*
functions.